from dash import Dash, html, dcc, dash_table
from dash.dash_table.Format import Format, Scheme
import dash_daq as daq
import plotly.express as px
import pandas as pd

app = Dash(__name__)

df = px.data.iris()
columns = [{"name": i, "id": i} for i in df.columns]
columns[0]['type'] = 'numeric'
columns[0]['format'] = Format(precision=2, scheme=Scheme.fixed)
columns[2]['selectable'] = True
columns[3]['selectable'] = True

app.layout = html.Div([
    html.H1('Dash Components'),
    html.Div([
        dcc.Graph(figure=px.scatter(df,x='sepal_length',y='sepal_width',color='species')),
        dcc.Tabs([
            dcc.Tab([
                'Dropdown',
                dcc.Dropdown([f'Item {i}' for i in range(10)]),html.Br(),
                'Input',
                dcc.Input(type='email'),html.Br(),
                'Checklist',
                dcc.Checklist([f'Multi-Select {i}' for i in range(4)]),html.Br(),
                'RadioItems',
                dcc.RadioItems([f'Single-Select {i}' for i in range(4)]),html.Br(),
                'DatePickerSingle',
                dcc.DatePickerSingle(),html.Br(),
                'DatePickerRange',
                dcc.DatePickerRange(),html.Br(),
                'Slider',
                dcc.Slider(min=0,max=10),html.Br(),
                'RangeSlider',
                dcc.RangeSlider(min=0,max=10),                
            ],label='Dash Core Components'),
            dcc.Tab([
                dash_table.DataTable(
                    df.to_dict('records'),
                    columns,
                    style_cell={'textAlign': 'left'},
                    style_data_conditional=[
                        {
                            'if': {'column_id': 'sepal_width',
                                   'filter_query': '{sepal_width} < 3'},
                            'backgroundColor': 'red'
                        }
                    ],
                    editable=True,
                    filter_action="native",
                    sort_action="native",
                    sort_mode="multi",
                    column_selectable="single",
                    row_selectable="multi",
                    row_deletable=True,
                    page_action="native",
                    page_current= 0,
                    page_size= 10,
                ) 
            ],label='DataTable'),
            dcc.Tab(['Gauge',
                daq.Gauge(
                    min=0,
                    max=10,
                    value=5
                ),'LEDDisplay',
                daq.LEDDisplay(
                    value=123
                ),'Thermometer',
                daq.Thermometer(
                    min=0,
                    max=10,
                    value=5
                ),'GraduatedBar',
                daq.GraduatedBar(
                    min=0,
                    max=10,
                    step=2,
                    value=5
                ),'Tank',
                daq.Tank(
                    min=0,
                    max=10,
                    value=5
                ),'Knob',
                daq.Knob(
                    min=0,
                    max=10,
                    value=5
                ),'Slider',
                daq.Slider(
                    min=0,
                    max=10,
                    value=5
                ),'ColorPicker',
                daq.ColorPicker(),
                 'ToggleSwitch',
                daq.ToggleSwitch() 
            ],label='DAQ')
        ]),
        
    ]),
])

app.run_server(debug=True)